@@ -1,6 +1,6 @@
 use fdt::node::FdtNode;
 
-static MY_FDT: &[u8] = include_bytes!("../test.dtb");
+static MY_FDT: &[u8] = include_bytes!("../dtb/test.dtb");
 
 fn main() {
     let fdt = fdt::Fdt::new(MY_FDT).unwrap();
